//
// Created by Grigoriy Khlytin on 01.12.2021.
//

#include "testlib.h"

using namespace std;

typedef long long ll;

vector<ll> gen_thue_morse(ll n) {
    vector<bool> t;
    t.reserve(2 * n);
    t.push_back(false);
    ll len = 1;
    while (len < n) {
        for (ll x = 0; x < len; x++)
            t.push_back(!t[x]);
        len = (ll) t.size();
    }
    vector<ll> s;
    s.reserve(n);
    for (ll i = 0; i < n; i++) {
        s.push_back(t[i] ? 1 : 0);
    }
    return s;
}

int main(int argc, char *argv[]) {
    registerGen(argc, argv, 1);

    ll typ = opt<ll>("type");
    ll MAX_N = opt<ll>("n");
    ll MAX_M = opt<ll>("m");
    ll MAX_W = opt<ll>("w");

    ll n = max(1LL, rnd.next(max(MAX_N / 2, MAX_N - 10), MAX_N));
    ll m = max(1LL, rnd.next(max(MAX_M / 2, MAX_M - 10), MAX_M));

    println(n, m);

    vector<ll> a(n), b(m);
    vector<ll> a_thue_morse;
    vector<ll> b_thue_morse;

    ll a_0, b_0, r;

    switch (typ) {
        case 1:
            for (ll i = 0; i < n; i++) {
                a[i] = rnd.next(1LL, MAX_W);
            }
            b_0 = rnd.next(1LL, MAX_W);
            for (ll i = 0; i < m; i++) {
                b[i] = b_0;
            }
            break;
        case 2:
            a_thue_morse = gen_thue_morse(n);
            a_0 = rnd.next(1LL, MAX_W - 1);
            for (ll i = 0; i < n; i++) {
                a[i] = a_thue_morse[i] + a_0;
            }
            b_0 = rnd.next(1LL, MAX_W);
            for (ll i = 0; i < m; i++) {
                b[i] = b_0;
            }
            break;
        case 3:
            a_thue_morse = gen_thue_morse(n);
            b_thue_morse = gen_thue_morse(m);
            a_0 = rnd.next(1LL, MAX_W - 1);
            for (ll i = 0; i < n; i++) {
                a[i] = a_thue_morse[i] + a_0;
            }
            b_0 = rnd.next(1LL, MAX_W - 1);
            for (ll i = 0; i < m; i++) {
                b[i] = b_thue_morse[i] + b_0;
            }
            break;
        case 4:
            a_0 = rnd.next(1LL, MAX_W);
            for (ll i = 0; i < n; i++) {
                a[i] = a_0;
            }
            b_0 = rnd.next(1LL, MAX_W);
            for (ll i = 0; i < m; i++) {
                b[i] = b_0;
            }
            a_0 = rnd.next(1LL, MAX_W);
            b_0 = rnd.next(1LL, MAX_W);
            for (ll i = 0; i < 2; i++) {
                r = rnd.next(0LL, n - 1);
                a[r] = a_0;
                r = rnd.next(0LL, m - 1);
                b[r] = b_0;
            }
            break;
        case 5:
            for (ll i = 0; i < n; i++) {
                a[i] = ((i + 1 + rnd.next(0LL, 1LL)) % MAX_W) + 1LL;
            }
            for (ll i = 0; i < m; i++) {
                b[i] = ((m - i + rnd.next(0LL, 1LL)) % MAX_W) + 1LL;
            }
            break;
        case 6:
            for (ll i = 0; i < n; i++) {
                a[i] = (i % MAX_W) + 1LL;
            }
            for (ll i = 0; i < m; i++) {
                b[i] = (i % MAX_W) + 1LL;
            }
            break;
        default:
            for (ll i = 0; i < n; i++) {
                a[i] = rnd.next(1LL, MAX_W);
            }
            for (ll i = 0; i < m; i++) {
                b[i] = rnd.next(1LL, MAX_W);
            }
            break;
    }

    println(a.begin(), a.end());

    println(b.begin(), b.end());

}
