//
// Created by Grigoriy Khlytin on 01.12.2021.
//

#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_set>

using namespace std;

typedef long long ll;
typedef unsigned long long ull;

const ull MA = 1e9 + 9;
const ull P = 239LL;

struct Num {
    ull a;

    explicit Num(ull a) : a(a) {}

    Num operator+(const Num &x) const {
        return Num((a + x.a) % MA);
    }

    Num operator-(const Num &x) const {
        return Num((a + MA - x.a) % MA);
    }

    Num operator*(const Num &x) const {
        return Num((a * x.a) % MA);
    }

    bool operator==(const Num &x) const {
        return a == x.a;
    }

    explicit operator ull() const {
        return a + 1;
    }
};

struct Seq {
    vector<ll> s, rev_s;
    vector<Num> deg, h, rev_h;

    explicit Seq(vector<ll> &str) : s(str), rev_s(str) {
        reverse(rev_s.begin(), rev_s.end());

        deg.resize(s.size() + 1, Num(1));
        h.resize(s.size() + 1, Num(0));
        rev_h.resize(s.size() + 1, Num(0));

        Num base = Num(P);

        for (ll i = 0; i < s.size(); i++) {
            deg[i + 1] = deg[i] * base;
            h[i + 1] = h[i] * base + Num(s[i]);
            rev_h[i + 1] = rev_h[i] * base + Num(rev_s[i]);
        }
    }

    Num get_hash(ll l, ll r) {
        return h[r + 1] - h[l] * deg[r - l + 1];
    }

    Num get_rev_hash(ll l, ll r) {
        ll new_l = (ll) s.size() - 1 - r;
        ll new_r = (ll) s.size() - 1 - l;
        return rev_h[new_r + 1] - rev_h[new_l] * deg[new_r - new_l + 1];
    }
};

bool check(ll k, Seq &first, Seq &second, bool isEven) {
    if (k < 0) {
        return true;
    }

    unordered_set<ull> cnt_hash;

    ll w;
    if (isEven) {
        w = 1;
    } else {
        w = 0;
    }

    for (ll i = 0; i < first.s.size(); i++) {
        if (0 <= i - k && i - k < first.s.size() &&
            0 <= i + k + w && i + k + w < first.s.size()) {

            Num x = first.get_hash(i - k, i) - first.get_rev_hash(i + w, i + k + w);

            cnt_hash.insert((ull) x);
        }
    }

    for (ll i = 0; i < second.s.size(); i++) {
        if (0 <= i - k && i - k < second.s.size() &&
            0 <= i + k + w && i + k + w < second.s.size()) {

            Num x = second.get_rev_hash(i + w, i + k + w) - second.get_hash(i - k, i);

            if (cnt_hash.count((ull) x) != 0) {
                return true;
            }
        }
    }

    return false;
}

//[l, r)
ll bin_search(Seq &first, Seq &second, bool isEven) {
    ll left = -1;
    ll right = min((ll) first.s.size(), (ll) second.s.size()) + 1;

    while (right - left > 1) {
        ll mid = left + (right - left) / 2;

        //check satisfaction 2 * mid + 2, if (isEven == true)
        //check satisfaction 2 * mid + 1, if (isEven == false)
        if (check(mid, first, second, isEven)) {
            left = mid;
        } else {
            right = mid;
        }

    }

    if (isEven) {
        return 2 * left + 2;
    } else {
        return 2 * left + 1;
    }
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    ll n, m;
    cin >> n >> m;

    vector<ll> a(n);
    vector<ll> b(m);

    for (ll i = 0; i < n; i++) {
        cin >> a[i];
    }

    for (ll j = 0; j < m; j++) {
        cin >> b[j];
    }

    Seq first(a), second(b);

    ll uneven_ans = bin_search(first, second, false);
    ll even_ans = bin_search(first, second, true);

    cout << max(uneven_ans, even_ans);

    return 0;
}
