//  Copyright 2021 Nikita Golikov

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
    #define debug(x) cerr << (#x) << ":\t" << (x) << endl
#else
    #define debug(x) 238;
#endif

template <class A, class B>
bool smin(A &x, B &&y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A &x, B &&y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

// #define FAST_RANDOM

#ifndef FAST_RANDOM
#ifdef GOLIKOV
mt19937_64 rng(566);
#else
mt19937_64 rng(chrono::steady_clock::now().time_since_epoch().count());
#endif

template <typename T>
T rnd_helper(T from, T to, true_type) {
  return uniform_int_distribution<T>(from, to)(rng);
}

template <typename T>
T rnd_helper(T from, T to, false_type) {
  return uniform_real_distribution<T>(from, to)(rng);
}

template <typename T>
T rnd(T from, T to) {
  return rnd_helper(from, to, is_integral<T>{});
}
#else
  using ui32 = uint32_t;
  ui32 SEED = 471241271;

  ui32 xorshift32() {
    SEED ^= SEED << 13u;
    SEED ^= SEED >> 17u;
    SEED ^= SEED << 5u;
    return SEED;
  }

  template <class T>
  T rnd_helper(T from, T to, false_type) {
    return from + (to - from) * (T(1) * xorshift32() / numeric_limits<ui32>::max());
  }

  template <class T>
  T rnd_helper(T from, T to, true_type) {
    return from + xorshift32() % (to - from + 1);
  }

  template <class T>
  T rnd(T from, T to) {
    return rnd_helper(from, to, is_integral<T>{});
  }
#endif

int const MOD1 = int(1e9 + 7);
int const MOD2 = int(1e9 + 9);
using hash_t = pair<int, int>;
hash_t BASE{rnd(2, MOD1 - 1), rnd(2, MOD2 - 1)};

int add(int x, int y, int MOD) {
  x += y;
  if (x >= MOD) {
    x -= MOD;
  }
  return x;
}

int sub(int x, int y, int MOD) {
  x -= y;
  if (x < 0) {
    x += MOD;
  }
  return x;
}

int mul(ll x, int y, int MOD) {
  return int(x * y % MOD);
}

hash_t add(hash_t x, hash_t y) {
  return hash_t{add(x.first, y.first, MOD1), add(x.second, y.second, MOD2)};
}
hash_t add(hash_t x, int y) {
  return hash_t{add(x.first, y, MOD1), add(x.second, y, MOD2)};
}
hash_t sub(hash_t x, hash_t y) {
  return hash_t{sub(x.first, y.first, MOD1), sub(x.second, y.second, MOD2)};
}
hash_t mul(hash_t x, hash_t y) {
  return hash_t{mul(x.first, y.first, MOD1), mul(x.second, y.second, MOD2)};
}

vector<hash_t> makeHash(vector<int> a) {
  int n = int(a.size());
  vector<hash_t> h(n + 1);
  for (int i = 0; i < n; ++i) {
    h[i + 1] = add(mul(h[i], BASE), a[i]);
  }
  return h;
}

#include <ext/pb_ds/assoc_container.hpp>
using namespace __gnu_pbds;

struct chash {
  static auto const C = (ull) 7e18 + 23;
  static_assert(C % 2);

  ull const RANDOM = chrono::steady_clock::now().time_since_epoch().count();
  ull operator()(ull x) const {
    return __builtin_bswap64((x ^ RANDOM) * C);
  }

  template <class A, class B>
  ull operator()(pair<A, B> const& p) const {
    return (*this)(p.first) * 31 + (*this)(p.second);
  }
};

template <class T> using hash_set = gp_hash_table<T, null_type, chash>;
template <class K, class V> using hash_map = gp_hash_table<K, V, chash>;

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  int n, m;
  cin >> n >> m;
  vector<int> a(n);
  for (auto& x : a) cin >> x;
  vector<int> b(m);
  for (auto& x : b) cin >> x;

  auto ra = a;
  reverse(ra.begin(), ra.end());
  auto rb = b;
  reverse(rb.begin(), rb.end());

  auto ha = makeHash(a);
  auto hra = makeHash(ra);
  auto hb = makeHash(b);
  auto hrb = makeHash(rb);

  vector<hash_t> pw(n + m + 10);
  pw[0] = hash_t{1, 1};
  for (int i = 1; i < int(pw.size()); ++i) {
    pw[i] = mul(pw[i - 1], BASE);
  }

  auto H = [&](auto& h, auto& rh, int from, int len) {
    int L = from;
    int R = from + len;
    hash_t forw = sub(h[R], mul(h[L], pw[R - L]));
    int nL = int(h.size()) - 1 - R;
    int nR = int(h.size()) - 1 - L;
    L = nL;
    R = nR;
    hash_t rev = sub(rh[R], mul(rh[L], pw[R - L]));
    return sub(forw, rev);
  };

  auto can = [&](int len) {
    if (len <= 0) {
      return true;
    }
    if (len > min(n, m)) {
      return false;
    }
    
    hash_set<hash_t> have;
    for (int i = 0; i + len <= n; ++i) {
      have.insert(H(ha, hra, i, len));
    }
    for (int i = 0; i + len <= m; ++i) {
      auto hc = H(hb, hrb, i, len);
      hc.first = (MOD1 - hc.first) % MOD1;
      hc.second = (MOD2 - hc.second) % MOD2;
      if (have.find(hc) != have.end()) {
        return true;
      }
    }
    return false;
  };

  int ans = 0;

  for (int p : {0, 1}) {
    int left = -1;
    int right = max(n, m) + 10;
    while (left + 1 != right) {
      int mid = (left + right) / 2;
      (can(2 * mid + p) ? left : right) = mid;
    }
    smax(ans, 2 * left + p);
  }

  cout << ans << '\n';

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
